require 'iron_mailer'

describe IronMailer::MqMailer do
  describe "initializer" do
    it "should accept the queue name" do
      IronMailer::MqMailer.new(queue_name: 'queue_name').queue_name.should == 'queue_name'
    end

    it "should accept the host" do
      IronMailer::MqMailer.new(host: 'host').host.should == 'host'
    end

  end

  describe "client" do
    before(:each) do
      @client=IronMQ::Client.new(:config=>'spec/config/iron_mq.json')

      ENV['IRON_MQ_TOKEN'] = @client.token
      ENV['IRON_MQ_PROJECT_ID'] = @client.project_id

    end
    it "should return a client with the given host" do
      IronMailer::MqMailer.new(host: 'mq-rackspace-lon.iron.io').client.host.should == 'mq-rackspace-lon.iron.io'
    end

    it "should handle no host being passed in" do
      IronMailer::MqMailer.new.client.host.should_not be_blank
    end
  end

  def test_email
    test_email = Mail.new do
      subject ="This is a subject"
      to 'to@someone.com'
      from 'from@someone.com'
      text_part do
        body "This is Text"
      end
      html_part do
        content_type  'text/html; charset=UTF-8'
        body "<h1>This is html</h1>"
      end
    end
  end

  describe "deliver!" do
    before(:each) do
      @queue_name='test_mail_queue'
      @client=IronMQ::Client.new(:config=>'spec/config/iron_mq.json')

      ENV['IRON_MQ_TOKEN'] = @client.token
      ENV['IRON_MQ_PROJECT_ID'] = @client.project_id

      @queue=@client.queue(@queue_name)
      @mailer = IronMailer::MqMailer.new(queue_name: @queue_name, host: 'mq-aws-eu-west-1-1.iron.io')
    end

    it "should add an email message to the queue" do
      lambda{
        @mailer.deliver!(test_email)
        @queue.reload
      }.should change(@queue, :size)
    end
  end
end